@@ -5,6 +5,11 @@ import imp
 import inspect
 import sys
 
+from recursely._compat import IS_PY3
+
+
+__all__ = ['ImportHook']
+
 
 class ImportHook(object):
     """Base class for import hooks, including both ``sys.meta_path``
@@ -17,15 +22,12 @@ class ImportHook(object):
     Alternativaly, it's possible to completely either the process
     of finding a module to import, or loading the module, or both.
     """
-    class __metaclass__(type):
-        """Metaclass for selecting a correct set of (abstract) base classes
-        depending on the Python version we are running.
-        """
-        def __new__(cls, name, bases, dict_):
-            if sys.version_info[0] >= 3:
-                from importlib import abc
-                bases = (abc.Finder, abc.Loader, abc.InspectLoader)
-            return type.__new__(cls, name, bases, dict_)
+    @classmethod
+    def is_installed(cls):
+        """Checks whether any instance of this import hook is installed."""
+        return any(isinstance(ih, cls) for ih in sys.meta_path)
+
+    # Overrideable import events
 
     def on_module_found(self, fullname, path):
         """Event triggered when module has been succesfully found
@@ -161,3 +163,8 @@ class ImportHook(object):
 
     def get_source(self, fullname):
         return inspect.getsource(self._import(fullname))
+
+if IS_PY3:
+    from importlib import abc
+    for ab in (abc.Finder, abc.Loader, abc.InspectLoader):
+        ab.register(ImportHook)
